You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by ps...@apache.org on 2011/02/15 02:31:14 UTC

svn commit: r1070725 [1/3] - in /commons/proper/math/branches/MATH_2_X/src: main/java/org/apache/commons/math/ main/java/org/apache/commons/math/analysis/ main/java/org/apache/commons/math/analysis/integration/ main/java/org/apache/commons/math/analysi...

Author: psteitz
Date: Tue Feb 15 01:31:12 2011
New Revision: 1070725

URL: http://svn.apache.org/viewvc?rev=1070725&view=rev
Log:
Reverted incompatible changes in the exception hierarchy.

Modified:
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/ArgumentOutsideDomainException.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/FunctionEvaluationException.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MathException.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MathRuntimeException.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MaxIterationsExceededException.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/ComposableFunction.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/MultivariateRealFunction.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/MultivariateVectorialFunction.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/UnivariateRealFunction.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/LegendreGaussIntegrator.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/RombergIntegrator.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/SimpsonIntegrator.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/TrapezoidIntegrator.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/UnivariateRealIntegrator.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/BisectionSolver.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/BrentSolver.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/LaguerreSolver.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/MullerSolver.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/NewtonSolver.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/RiddersSolver.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/SecantSolver.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/UnivariateRealSolver.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/UnivariateRealSolverImpl.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/UnivariateRealSolverUtils.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/linear/AbstractRealVector.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/linear/MatrixVisitorException.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/linear/RealVector.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/ode/events/EventState.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/LeastSquaresConverter.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/MultiStartUnivariateRealOptimizer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/UnivariateRealOptimizer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/direct/DirectSearchOptimizer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/direct/MultiDirectional.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/direct/NelderMead.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/direct/PowellOptimizer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/general/NonLinearConjugateGradientOptimizer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/univariate/AbstractUnivariateRealOptimizer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/univariate/BracketFinder.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/optimization/univariate/BrentOptimizer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/transform/FastCosineTransformer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/transform/FastFourierTransformer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/transform/FastHadamardTransformer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/transform/FastSineTransformer.java
    commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/transform/RealTransformer.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/ArgumentOutsideDomainExceptionTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/analysis/BinaryFunctionTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/analysis/ComposableFunctionTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/analysis/MonitoredFunction.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/analysis/SumSincFunction.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/analysis/integration/LegendreGaussIntegratorTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/analysis/polynomials/PolynomialFunctionTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/ode/events/EventStateTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/optimization/direct/MultiDirectionalTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/optimization/direct/NelderMeadTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/optimization/univariate/BrentOptimizerTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/transform/FastCosineTransformerTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/transform/FastFourierTransformerTest.java
    commons/proper/math/branches/MATH_2_X/src/test/java/org/apache/commons/math/transform/FastSineTransformerTest.java

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/ArgumentOutsideDomainException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/ArgumentOutsideDomainException.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/ArgumentOutsideDomainException.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/ArgumentOutsideDomainException.java Tue Feb 15 01:31:12 2011
@@ -17,7 +17,6 @@
 
 package org.apache.commons.math;
 
-import org.apache.commons.math.exception.MathIllegalNumberException;
 import org.apache.commons.math.exception.util.LocalizedFormats;
 
 /**
@@ -26,7 +25,7 @@ import org.apache.commons.math.exception
  * @since 1.2
  * @version $Revision$ $Date$
  */
-public class ArgumentOutsideDomainException extends MathIllegalNumberException {
+public class ArgumentOutsideDomainException extends FunctionEvaluationException {
 
     /** Serializable version identifier. */
     private static final long serialVersionUID = -4965972841162580234L;
@@ -39,7 +38,7 @@ public class ArgumentOutsideDomainExcept
      * @param upper upper bound of the domain
      */
     public ArgumentOutsideDomainException(double argument, double lower, double upper) {
-        super(LocalizedFormats.ARGUMENT_OUTSIDE_DOMAIN, argument, lower, upper);
+        super(argument, LocalizedFormats.ARGUMENT_OUTSIDE_DOMAIN, argument, lower, upper);
     }
 
 }

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/FunctionEvaluationException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/FunctionEvaluationException.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/FunctionEvaluationException.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/FunctionEvaluationException.java Tue Feb 15 01:31:12 2011
@@ -28,10 +28,7 @@ import org.apache.commons.math.linear.Ar
  * caused the function evaluation to fail.
  *
  * @version $Revision$ $Date$
- * @deprecated in 2.2 (to be removed in 3.0). Please use
- * {@link org.apache.commons.math.exception.MathUserException} instead.
  */
-@Deprecated
 public class FunctionEvaluationException extends MathException  {
 
     /** Serializable version identifier. */

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MathException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MathException.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MathException.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MathException.java Tue Feb 15 01:31:12 2011
@@ -35,8 +35,6 @@ import org.apache.commons.math.exception
  * Adapted from <a href="http://commons.apache.org/collections/api-release/org/apache/commons/collections/FunctorException.html"/>.</p>
  *
  * @version $Revision$ $Date$
- * @deprecated in 2.2. Occurrences will be replaced in 3.0 by more specific
- * (and unchecked) exceptions.
  */
 public class MathException extends Exception implements MathThrowable {
 

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MathRuntimeException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MathRuntimeException.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MathRuntimeException.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MathRuntimeException.java Tue Feb 15 01:31:12 2011
@@ -36,7 +36,6 @@ import org.apache.commons.math.exception
 *
 * @version $Revision$ $Date$
 * @since 2.0
-* @deprecated in 2.2 (to be removed in 3.0).
 */
 public class MathRuntimeException extends RuntimeException implements MathThrowable {
 

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MaxIterationsExceededException.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MaxIterationsExceededException.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MaxIterationsExceededException.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/MaxIterationsExceededException.java Tue Feb 15 01:31:12 2011
@@ -28,7 +28,6 @@ import org.apache.commons.math.exception
  *
  * @version $Revision$ $Date$
  * @since 1.2
- * @deprecated in 2.2 (to be removed in 3.0).
  */
 public class MaxIterationsExceededException extends ConvergenceException {
 

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/ComposableFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/ComposableFunction.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/ComposableFunction.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/ComposableFunction.java Tue Feb 15 01:31:12 2011
@@ -17,7 +17,7 @@
 
 package org.apache.commons.math.analysis;
 
-import org.apache.commons.math.exception.MathUserException;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.util.FastMath;
 
 
@@ -26,9 +26,7 @@ import org.apache.commons.math.util.Fast
  *
  * @since 2.1
  * @version $Revision$ $Date$
- * @deprecated in 2.2
  */
-@Deprecated
 public abstract class ComposableFunction implements UnivariateRealFunction {
 
     /** The constant function always returning 0. */
@@ -286,7 +284,7 @@ public abstract class ComposableFunction
         return new ComposableFunction() {
             @Override
             /** {@inheritDoc} */
-            public double value(double x) throws MathUserException {
+            public double value(double x) throws FunctionEvaluationException {
                 return ComposableFunction.this.value(f.value(x));
             }
         };
@@ -305,7 +303,7 @@ public abstract class ComposableFunction
         return new ComposableFunction() {
             @Override
             /** {@inheritDoc} */
-            public double value(double x) throws MathUserException {
+            public double value(double x) throws FunctionEvaluationException {
                 return f.value(ComposableFunction.this.value(x));
             }
         };
@@ -326,7 +324,7 @@ public abstract class ComposableFunction
         return new ComposableFunction() {
             @Override
             /** {@inheritDoc} */
-            public double value(double x) throws MathUserException {
+            public double value(double x) throws FunctionEvaluationException {
                 return combiner.value(ComposableFunction.this.value(x), f.value(x));
             }
         };
@@ -341,7 +339,7 @@ public abstract class ComposableFunction
         return new ComposableFunction() {
             @Override
             /** {@inheritDoc} */
-            public double value(double x) throws MathUserException {
+            public double value(double x) throws FunctionEvaluationException {
                 return ComposableFunction.this.value(x) + f.value(x);
             }
         };
@@ -356,7 +354,7 @@ public abstract class ComposableFunction
         return new ComposableFunction() {
             @Override
             /** {@inheritDoc} */
-            public double value(double x) throws MathUserException {
+            public double value(double x) throws FunctionEvaluationException {
                 return ComposableFunction.this.value(x) + a;
             }
         };
@@ -371,7 +369,7 @@ public abstract class ComposableFunction
         return new ComposableFunction() {
             @Override
             /** {@inheritDoc} */
-            public double value(double x) throws MathUserException {
+            public double value(double x) throws FunctionEvaluationException {
                 return ComposableFunction.this.value(x) - f.value(x);
             }
         };
@@ -386,7 +384,7 @@ public abstract class ComposableFunction
         return new ComposableFunction() {
             @Override
             /** {@inheritDoc} */
-            public double value(double x) throws MathUserException {
+            public double value(double x) throws FunctionEvaluationException {
                 return ComposableFunction.this.value(x) * f.value(x);
             }
         };
@@ -401,7 +399,7 @@ public abstract class ComposableFunction
         return new ComposableFunction() {
             @Override
             /** {@inheritDoc} */
-            public double value(double x) throws MathUserException {
+            public double value(double x) throws FunctionEvaluationException {
                 return ComposableFunction.this.value(x) * scaleFactor;
             }
         };
@@ -415,7 +413,7 @@ public abstract class ComposableFunction
         return new ComposableFunction() {
             @Override
             /** {@inheritDoc} */
-            public double value(double x) throws MathUserException {
+            public double value(double x) throws FunctionEvaluationException {
                 return ComposableFunction.this.value(x) / f.value(x);
             }
         };
@@ -435,7 +433,7 @@ public abstract class ComposableFunction
      * </p>
      * @param combiner combiner to use between entries
      * @param initialValue initial value to use before first entry
-     * @return a new function that iteratively applie instance function on all
+     * @return a new function that iteratively apply instance function on all
      * elements of an array.
      */
     public MultivariateRealFunction asCollector(final BivariateRealFunction combiner,
@@ -443,7 +441,7 @@ public abstract class ComposableFunction
         return new MultivariateRealFunction() {
             /** {@inheritDoc} */
             public double value(double[] point)
-                throws MathUserException, IllegalArgumentException {
+                throws FunctionEvaluationException, IllegalArgumentException {
                 double result = initialValue;
                 for (final double entry : point) {
                     result = combiner.value(result, ComposableFunction.this.value(entry));
@@ -461,7 +459,7 @@ public abstract class ComposableFunction
      * #asCollector(BivariateRealFunction, double) asCollector(BivariateRealFunction, 0.0)}.
      * </p>
      * @param combiner combiner to use between entries
-     * @return a new function that iteratively applie instance function on all
+     * @return a new function that iteratively apply instance function on all
      * elements of an array.
      * @see #asCollector(BivariateRealFunction, double)
      */
@@ -477,7 +475,7 @@ public abstract class ComposableFunction
      * #asCollector(BivariateRealFunction, double) asCollector(BinaryFunction.ADD, initialValue)}.
      * </p>
      * @param initialValue initial value to use before first entry
-     * @return a new function that iteratively applie instance function on all
+     * @return a new function that iteratively apply instance function on all
      * elements of an array.
      * @see #asCollector(BivariateRealFunction, double)
      * @see BinaryFunction#ADD
@@ -493,7 +491,7 @@ public abstract class ComposableFunction
      * Calling this method is equivalent to call {@link
      * #asCollector(BivariateRealFunction, double) asCollector(BinaryFunction.ADD, 0.0)}.
      * </p>
-     * @return a new function that iteratively applie instance function on all
+     * @return a new function that iteratively apply instance function on all
      * elements of an array.
      * @see #asCollector(BivariateRealFunction, double)
      * @see BinaryFunction#ADD
@@ -503,6 +501,6 @@ public abstract class ComposableFunction
     }
 
     /** {@inheritDoc} */
-    public abstract double value(double x) throws MathUserException;
+    public abstract double value(double x) throws FunctionEvaluationException;
 
 }

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/MultivariateRealFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/MultivariateRealFunction.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/RombergIntegrator.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/RombergIntegrator.java Tue Feb 15 01:31:12 2011
@@ -16,10 +16,10 @@
  */
 package org.apache.commons.math.analysis.integration;
 
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.util.FastMath;
 
@@ -60,13 +60,13 @@ public class RombergIntegrator extends U
     /** {@inheritDoc} */
     @Deprecated
     public double integrate(final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException, IllegalArgumentException {
+        throws MaxIterationsExceededException, FunctionEvaluationException, IllegalArgumentException {
         return integrate(f, min, max);
     }
 
     /** {@inheritDoc} */
     public double integrate(final UnivariateRealFunction f, final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException, IllegalArgumentException {
+        throws MaxIterationsExceededException, FunctionEvaluationException, IllegalArgumentException {
 
         final int m = maximalIterationCount + 1;
         double previousRow[] = new double[m];

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/SimpsonIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/SimpsonIntegrator.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/SimpsonIntegrator.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/SimpsonIntegrator.java Tue Feb 15 01:31:12 2011
@@ -16,10 +16,10 @@
  */
 package org.apache.commons.math.analysis.integration;
 
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.util.FastMath;
 
@@ -59,13 +59,13 @@ public class SimpsonIntegrator extends U
     /** {@inheritDoc} */
     @Deprecated
     public double integrate(final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException, IllegalArgumentException {
+        throws MaxIterationsExceededException, FunctionEvaluationException, IllegalArgumentException {
         return integrate(f, min, max);
     }
 
     /** {@inheritDoc} */
     public double integrate(final UnivariateRealFunction f, final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException, IllegalArgumentException {
+        throws MaxIterationsExceededException, FunctionEvaluationException, IllegalArgumentException {
 
         clearResult();
         verifyInterval(min, max);

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/TrapezoidIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/TrapezoidIntegrator.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/BisectionSolver.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/BisectionSolver.java Tue Feb 15 01:31:12 2011
@@ -16,9 +16,9 @@
  */
 package org.apache.commons.math.analysis.solvers;
 
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.util.FastMath;
 
 /**
@@ -56,14 +56,14 @@ public class BisectionSolver extends Uni
     /** {@inheritDoc} */
     @Deprecated
     public double solve(double min, double max, double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         return solve(f, min, max);
     }
 
     /** {@inheritDoc} */
     @Deprecated
     public double solve(double min, double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         return solve(f, min, max);
     }
 
@@ -73,21 +73,21 @@ public class BisectionSolver extends Uni
      */
     @Deprecated
     public double solve(final UnivariateRealFunction f, double min, double max, double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         return solve(f, min, max);
     }
 
     /** {@inheritDoc} */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f, double min, double max, double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         return solve(maxEval, f, min, max);
     }
 
     /** {@inheritDoc} */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f, double min, double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max);
     }
@@ -98,7 +98,7 @@ public class BisectionSolver extends Uni
      */
     @Deprecated
     public double solve(final UnivariateRealFunction f, double min, double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
 
         clearResult();
         verifyInterval(min,max);

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/BrentSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/BrentSolver.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/MultivariateRealFunction.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/MultivariateRealFunction.java Tue Feb 15 01:31:12 2011
@@ -17,7 +17,7 @@
 
 package org.apache.commons.math.analysis;
 
-import org.apache.commons.math.exception.MathUserException;
+import org.apache.commons.math.FunctionEvaluationException;
 
 /**
  * An interface representing a multivariate real function.
@@ -30,10 +30,10 @@ public interface MultivariateRealFunctio
      * Compute the value for the function at the given point.
      * @param point point at which the function must be evaluated
      * @return function value for the given point
      * @exception MathUserException if the function evaluation fails
      * @exception IllegalArgumentException if points dimension is wrong
      */
     double value(double[] point)
-        throws MathUserException, IllegalArgumentException;
+        throws FunctionEvaluationException, IllegalArgumentException;
 
 }
@@ -30,10 +30,10 @@ public interface MultivariateRealFunctio
      * @param point point at which the function must be evaluated
      * @return function value for the given point
-     * @exception MathUserException if the function evaluation fails
+     * @exception FunctionEvaluationException if the function evaluation fails
      * @exception IllegalArgumentException if points dimension is wrong
      */

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/MultivariateVectorialFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/MultivariateVectorialFunction.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/MultivariateVectorialFunction.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/MultivariateVectorialFunction.java Tue Feb 15 01:31:12 2011
@@ -17,7 +17,7 @@
 
 package org.apache.commons.math.analysis;
 
-import org.apache.commons.math.exception.MathUserException;
+import org.apache.commons.math.FunctionEvaluationException;
 
 /**
  * An interface representing a multivariate vectorial function.
@@ -30,10 +30,10 @@ public interface MultivariateVectorialFu
      * Compute the value for the function at the given point.
      * @param point point at which the function must be evaluated
      * @return function value for the given point
      * @exception MathUserException if the function evaluation fails
      * @exception IllegalArgumentException if points dimension is wrong
      */
     double[] value(double[] point)
-        throws MathUserException, IllegalArgumentException;
+        throws FunctionEvaluationException, IllegalArgumentException;
 
 }
@@ -30,10 +30,10 @@ public interface MultivariateVectorialFu
      * @param point point at which the function must be evaluated
      * @return function value for the given point
-     * @exception MathUserException if the function evaluation fails
+     * @exception FunctionEvaluationException if the function evaluation fails
      * @exception IllegalArgumentException if points dimension is wrong
      */

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/UnivariateRealFunction.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/UnivariateRealFunction.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/UnivariateRealFunction.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/UnivariateRealFunction.java Tue Feb 15 01:31:12 2011
@@ -16,7 +16,7 @@
  */
 package org.apache.commons.math.analysis;
 
-import org.apache.commons.math.exception.MathUserException;
+import org.apache.commons.math.FunctionEvaluationException;
 
 /**
  * An interface representing a univariate real function.
@@ -29,8 +29,8 @@ public interface UnivariateRealFunction 
      * Compute the value for the function.
      * @param x the point for which the function value should be computed
      * @return the value
      * @throws MathUserException if the function evaluation fails
      */
-    double value(double x) throws MathUserException;
+    double value(double x) throws FunctionEvaluationException;
 
 }
@@ -29,8 +29,8 @@ public interface UnivariateRealFunction 
      * @param x the point for which the function value should be computed
      * @return the value
-     * @throws MathUserException if the function evaluation fails
+     * @throws FunctionEvaluationException if the function evaluation fails
      */

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/LegendreGaussIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/LegendreGaussIntegrator.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/LegendreGaussIntegrator.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/LegendreGaussIntegrator.java Tue Feb 15 01:31:12 2011
@@ -17,10 +17,10 @@
 package org.apache.commons.math.analysis.integration;
 
 import org.apache.commons.math.ConvergenceException;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.util.FastMath;
 
@@ -31,7 +31,7 @@ import org.apache.commons.math.util.Fast
  * Legendre-Gauss integrators are efficient integrators that can
  * accurately integrate functions with few functions evaluations. A
  * Legendre-Gauss integrator using an n-points quadrature formula can
- * integrate exactly 2n-1 degree polynomialss.
+ * integrate exactly 2n-1 degree polynomials.
  * </p>
  * <p>
  * These integrators evaluate the function on n carefully chosen
@@ -119,7 +119,8 @@ public class LegendreGaussIntegrator ext
     /** Weights for the current method. */
     private final double[] weights;
 
-    /** Build a Legendre-Gauss integrator.
+    /**
+     * Build a Legendre-Gauss integrator.
      * @param n number of points desired (must be between 2 and 5 inclusive)
      * @param defaultMaximalIterationCount maximum number of iterations
      * @exception IllegalArgumentException if the number of points is not
@@ -156,13 +157,13 @@ public class LegendreGaussIntegrator ext
     /** {@inheritDoc} */
     @Deprecated
     public double integrate(final double min, final double max)
-        throws ConvergenceException,  MathUserException, IllegalArgumentException {
+        throws ConvergenceException,  FunctionEvaluationException, IllegalArgumentException {
         return integrate(f, min, max);
     }
 
     /** {@inheritDoc} */
     public double integrate(final UnivariateRealFunction f, final double min, final double max)
-        throws ConvergenceException,  MathUserException, IllegalArgumentException {
+        throws ConvergenceException,  FunctionEvaluationException, IllegalArgumentException {
 
         clearResult();
         verifyInterval(min, max);
@@ -207,12 +208,12 @@ public class LegendreGaussIntegrator ext
      * @param max the upper bound for the interval
      * @param n number of steps
      * @return the value of n-th stage integral
      * @throws MathUserException if an error occurs evaluating the
      * function
      */
     private double stage(final UnivariateRealFunction f,
                          final double min, final double max, final int n)
-        throws MathUserException {
+        throws FunctionEvaluationException {
 
         // set up the step for the current stage
         final double step     = (max - min) / n;
@@ -207,12 +208,12 @@ public class LegendreGaussIntegrator ext
      * @param n number of steps
      * @return the value of n-th stage integral
-     * @throws MathUserException if an error occurs evaluating the
+     * @throws FunctionEvaluationException if an error occurs evaluating the
      * function
      */

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/RombergIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/RombergIntegrator.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/TrapezoidIntegrator.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/TrapezoidIntegrator.java Tue Feb 15 01:31:12 2011
@@ -16,10 +16,10 @@
  */
 package org.apache.commons.math.analysis.integration;
 
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.util.FastMath;
 
@@ -72,11 +72,11 @@ public class TrapezoidIntegrator extends
      * @param max the upper bound for the interval
      * @param n the stage of 1/2 refinement, n = 0 is no refinement
      * @return the value of n-th stage integral
      * @throws MathUserException if an error occurs evaluating the function
      */
     double stage(final UnivariateRealFunction f,
                  final double min, final double max, final int n)
-        throws MathUserException {
+        throws FunctionEvaluationException {
 
         if (n == 0) {
             s = 0.5 * (max - min) * (f.value(min) + f.value(max));
@@ -99,13 +99,13 @@ public class TrapezoidIntegrator extends
     /** {@inheritDoc} */
     @Deprecated
     public double integrate(final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException, IllegalArgumentException {
+        throws MaxIterationsExceededException, FunctionEvaluationException, IllegalArgumentException {
         return integrate(f, min, max);
     }
 
     /** {@inheritDoc} */
     public double integrate(final UnivariateRealFunction f, final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException, IllegalArgumentException {
+        throws MaxIterationsExceededException, FunctionEvaluationException, IllegalArgumentException {
 
         clearResult();
         verifyInterval(min, max);
@@ -72,11 +72,11 @@ public class TrapezoidIntegrator extends
      * @param n the stage of 1/2 refinement, n = 0 is no refinement
      * @return the value of n-th stage integral
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      */
     double stage(final UnivariateRealFunction f,

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/UnivariateRealIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/UnivariateRealIntegrator.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/UnivariateRealIntegrator.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/integration/UnivariateRealIntegrator.java Tue Feb 15 01:31:12 2011
@@ -18,8 +18,8 @@ package org.apache.commons.math.analysis
 
 import org.apache.commons.math.ConvergenceException;
 import org.apache.commons.math.ConvergingAlgorithm;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 
 /**
  * Interface for univariate real integration algorithms.
@@ -67,7 +67,7 @@ public interface UnivariateRealIntegrato
      * @return the value of integral
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the integrator detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the
      * function
      * @throws IllegalArgumentException if min > max or the endpoints do not
      * satisfy the requirements specified by the integrator
@@ -76,7 +76,7 @@ public interface UnivariateRealIntegrato
      */
     @Deprecated
     double integrate(double min, double max)
-        throws ConvergenceException, MathUserException, IllegalArgumentException;
+        throws ConvergenceException, FunctionEvaluationException, IllegalArgumentException;
 
     /**
      * Integrate the function in the given interval.
@@ -87,12 +87,12 @@ public interface UnivariateRealIntegrato
      * @return the value of integral
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the integrator detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min > max or the endpoints do not
      * satisfy the requirements specified by the integrator
      */
     double integrate(UnivariateRealFunction f, double min, double max)
-        throws ConvergenceException, MathUserException, IllegalArgumentException;
+        throws ConvergenceException, FunctionEvaluationException, IllegalArgumentException;
 
     /**
      * Get the result of the last run of the integrator.
@@ -67,7 +67,7 @@ public interface UnivariateRealIntegrato
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the integrator detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the
+     * @throws FunctionEvaluationException if an error occurs evaluating the
      * function
      * @throws IllegalArgumentException if min > max or the endpoints do not
@@ -87,12 +87,12 @@ public interface UnivariateRealIntegrato
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the integrator detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min > max or the endpoints do not
      * satisfy the requirements specified by the integrator

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/BisectionSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/BisectionSolver.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/BrentSolver.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/BrentSolver.java Tue Feb 15 01:31:12 2011
@@ -17,10 +17,10 @@
 package org.apache.commons.math.analysis.solvers;
 
 
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.util.FastMath;
 
@@ -95,14 +95,14 @@ public class BrentSolver extends Univari
     /** {@inheritDoc} */
     @Deprecated
     public double solve(double min, double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         return solve(f, min, max);
     }
 
     /** {@inheritDoc} */
     @Deprecated
     public double solve(double min, double max, double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         return solve(f, min, max, initial);
     }
 
@@ -120,7 +120,7 @@ public class BrentSolver extends Univari
      * initial point is known).
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating  the function
      * @throws IllegalArgumentException if initial is not between min and max
      * (even if it <em>is</em> a root)
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -128,7 +128,7 @@ public class BrentSolver extends Univari
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max, final double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
 
         clearResult();
         if ((initial < min) || (initial > max)) {
@@ -188,14 +188,14 @@ public class BrentSolver extends Univari
      * @param maxEval Maximum number of evaluations.
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating  the function
      * @throws IllegalArgumentException if initial is not between min and max
      * (even if it <em>is</em> a root)
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max, final double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max, initial);
     }
@@ -212,7 +212,7 @@ public class BrentSolver extends Univari
      * @param max the upper bound for the interval.
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -220,7 +220,7 @@ public class BrentSolver extends Univari
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
 
         clearResult();
         verifyInterval(min, max);
@@ -273,14 +273,14 @@ public class BrentSolver extends Univari
      * @param maxEval Maximum number of evaluations.
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max);
     }
@@ -298,13 +298,13 @@ public class BrentSolver extends Univari
      * @param y2 function value at the bracket point.
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      */
     private double solve(final UnivariateRealFunction f,
                          double x0, double y0,
                          double x1, double y1,
                          double x2, double y2)
-    throws MaxIterationsExceededException, MathUserException {
+    throws MaxIterationsExceededException, FunctionEvaluationException {
 
         double delta = x1 - x0;
         double oldDelta = delta;
@@ -120,7 +120,7 @@ public class BrentSolver extends Univari
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating  the function
+     * @throws FunctionEvaluationException if an error occurs evaluating  the function
      * @throws IllegalArgumentException if initial is not between min and max
      * (even if it <em>is</em> a root)
@@ -188,14 +188,14 @@ public class BrentSolver extends Univari
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating  the function
+     * @throws FunctionEvaluationException if an error occurs evaluating  the function
      * @throws IllegalArgumentException if initial is not between min and max
      * (even if it <em>is</em> a root)
@@ -212,7 +212,7 @@ public class BrentSolver extends Univari
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
@@ -273,14 +273,14 @@ public class BrentSolver extends Univari
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
@@ -298,13 +298,13 @@ public class BrentSolver extends Univari
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      */
     private double solve(final UnivariateRealFunction f,

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/LaguerreSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/LaguerreSolver.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/LaguerreSolver.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/LaguerreSolver.java Tue Feb 15 01:31:12 2011
@@ -17,12 +17,12 @@
 package org.apache.commons.math.analysis.solvers;
 
 import org.apache.commons.math.ConvergenceException;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
 import org.apache.commons.math.analysis.polynomials.PolynomialFunction;
 import org.apache.commons.math.complex.Complex;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.util.FastMath;
 
@@ -90,14 +90,14 @@ public class LaguerreSolver extends Univ
     /** {@inheritDoc} */
     @Deprecated
     public double solve(final double min, final double max)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
         return solve(p, min, max);
     }
 
     /** {@inheritDoc} */
     @Deprecated
     public double solve(final double min, final double max, final double initial)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
         return solve(p, min, max, initial);
     }
 
@@ -114,13 +114,13 @@ public class LaguerreSolver extends Univ
      * @return the point at which the function value is zero
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max, final double initial)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max, initial);
     }
@@ -137,14 +137,14 @@ public class LaguerreSolver extends Univ
      * @return the point at which the function value is zero
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
      */
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max, final double initial)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
 
         // check for zeros before verifying bracketing
         if (f.value(min) == 0.0) {
@@ -183,13 +183,13 @@ public class LaguerreSolver extends Univ
      * @return the point at which the function value is zero
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max);
     }
@@ -209,14 +209,14 @@ public class LaguerreSolver extends Univ
      * @return the point at which the function value is zero
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
      */
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
 
         // check function type
         if (!(f instanceof PolynomialFunction)) {
@@ -278,13 +278,13 @@ public class LaguerreSolver extends Univ
      * @return the point at which the function value is zero
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2.
      */
     @Deprecated
     public Complex[] solveAll(double coefficients[], double initial) throws
-        ConvergenceException, MathUserException {
+        ConvergenceException, FunctionEvaluationException {
 
         Complex c[] = new Complex[coefficients.length];
         Complex z = new Complex(initial, 0.0);
@@ -303,13 +303,13 @@ public class LaguerreSolver extends Univ
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2.
      */
     @Deprecated
     public Complex[] solveAll(Complex coefficients[], Complex initial) throws
-        MaxIterationsExceededException, MathUserException {
+        MaxIterationsExceededException, FunctionEvaluationException {
 
         int n = coefficients.length - 1;
         int iterationCount = 0;
@@ -353,13 +353,13 @@ public class LaguerreSolver extends Univ
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2.
      */
     @Deprecated
     public Complex solve(Complex coefficients[], Complex initial) throws
-        MaxIterationsExceededException, MathUserException {
+        MaxIterationsExceededException, FunctionEvaluationException {
 
         int n = coefficients.length - 1;
         if (n < 1) {
@@ -114,13 +114,13 @@ public class LaguerreSolver extends Univ
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
@@ -137,14 +137,14 @@ public class LaguerreSolver extends Univ
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -183,13 +183,13 @@ public class LaguerreSolver extends Univ
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
@@ -209,14 +209,14 @@ public class LaguerreSolver extends Univ
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -278,13 +278,13 @@ public class LaguerreSolver extends Univ
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2.
@@ -303,13 +303,13 @@ public class LaguerreSolver extends Univ
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2.
@@ -353,13 +353,13 @@ public class LaguerreSolver extends Univ
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2.

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/MullerSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/MullerSolver.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/MullerSolver.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/MullerSolver.java Tue Feb 15 01:31:12 2011
@@ -17,9 +17,9 @@
 package org.apache.commons.math.analysis.solvers;
 
 import org.apache.commons.math.ConvergenceException;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.util.FastMath;
 import org.apache.commons.math.util.MathUtils;
 
@@ -64,14 +64,14 @@ public class MullerSolver extends Univar
     /** {@inheritDoc} */
     @Deprecated
     public double solve(final double min, final double max)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
         return solve(f, min, max);
     }
 
     /** {@inheritDoc} */
     @Deprecated
     public double solve(final double min, final double max, final double initial)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
         return solve(f, min, max, initial);
     }
 
@@ -88,13 +88,13 @@ public class MullerSolver extends Univar
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max, final double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max, initial);
     }
@@ -111,14 +111,14 @@ public class MullerSolver extends Univar
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
      */
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max, final double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
 
         // check for zeros before verifying bracketing
         if (f.value(min) == 0.0) { return min; }
@@ -156,13 +156,13 @@ public class MullerSolver extends Univar
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max);
     }
@@ -188,14 +188,14 @@ public class MullerSolver extends Univar
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
      */
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
 
         // [x0, x2] is the bracketing interval in each iteration
         // x1 is the last approximation and an interpolation point in (x0, x2)
@@ -299,14 +299,14 @@ public class MullerSolver extends Univar
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated replaced by {@link #solve2(UnivariateRealFunction, double, double)}
      * since 2.0
      */
     @Deprecated
     public double solve2(final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         return solve2(f, min, max);
     }
 
@@ -332,14 +332,14 @@ public class MullerSolver extends Univar
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
      */
     @Deprecated
     public double solve2(final UnivariateRealFunction f,
                          final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
 
         // x2 is the last root approximation
         // x is the new approximation and new x2 for next round
@@ -88,13 +88,13 @@ public class MullerSolver extends Univar
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
@@ -111,14 +111,14 @@ public class MullerSolver extends Univar
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -156,13 +156,13 @@ public class MullerSolver extends Univar
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
@@ -188,14 +188,14 @@ public class MullerSolver extends Univar
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -299,14 +299,14 @@ public class MullerSolver extends Univar
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated replaced by {@link #solve2(UnivariateRealFunction, double, double)}
@@ -332,14 +332,14 @@ public class MullerSolver extends Univar
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/NewtonSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/NewtonSolver.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/NewtonSolver.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/NewtonSolver.java Tue Feb 15 01:31:12 2011
@@ -17,11 +17,11 @@
 
 package org.apache.commons.math.analysis.solvers;
 
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.DifferentiableUnivariateRealFunction;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.util.FastMath;
 
@@ -60,14 +60,14 @@ public class NewtonSolver extends Univar
     /** {@inheritDoc} */
     @Deprecated
     public double solve(final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException  {
+        throws MaxIterationsExceededException, FunctionEvaluationException  {
         return solve(f, min, max);
     }
 
     /** {@inheritDoc} */
     @Deprecated
     public double solve(final double min, final double max, final double startValue)
-        throws MaxIterationsExceededException, MathUserException  {
+        throws MaxIterationsExceededException, FunctionEvaluationException  {
         return solve(f, min, max, startValue);
     }
 
@@ -80,13 +80,13 @@ public class NewtonSolver extends Univar
      * @param maxEval Maximum number of evaluations.
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function or derivative
      * @throws IllegalArgumentException if min is not less than max
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException  {
+        throws MaxIterationsExceededException, FunctionEvaluationException  {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max);
     }
@@ -99,14 +99,14 @@ public class NewtonSolver extends Univar
      * @param max the upper bound for the interval
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function or derivative
      * @throws IllegalArgumentException if min is not less than max
      * @deprecated in 2.2 (to be removed in 3.0).
      */
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException  {
+        throws MaxIterationsExceededException, FunctionEvaluationException  {
         return solve(f, min, max, UnivariateRealSolverUtils.midpoint(min, max));
     }
 
@@ -120,14 +120,14 @@ public class NewtonSolver extends Univar
      * @param maxEval Maximum number of evaluations.
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function or derivative
      * @throws IllegalArgumentException if startValue is not between min and max or
      * if function is not a {@link DifferentiableUnivariateRealFunction} instance
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max, final double startValue)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max, startValue);
     }
@@ -141,7 +141,7 @@ public class NewtonSolver extends Univar
      * @param startValue the start value to use.
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function or derivative
      * @throws IllegalArgumentException if startValue is not between min and max or
      * if function is not a {@link DifferentiableUnivariateRealFunction} instance
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -149,7 +149,7 @@ public class NewtonSolver extends Univar
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max, final double startValue)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
 
         try {
 
@@ -80,13 +80,13 @@ public class NewtonSolver extends Univar
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function or derivative
+     * @throws FunctionEvaluationException if an error occurs evaluating the function or derivative
      * @throws IllegalArgumentException if min is not less than max
      */
@@ -99,14 +99,14 @@ public class NewtonSolver extends Univar
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function or derivative
+     * @throws FunctionEvaluationException if an error occurs evaluating the function or derivative
      * @throws IllegalArgumentException if min is not less than max
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -120,14 +120,14 @@ public class NewtonSolver extends Univar
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function or derivative
+     * @throws FunctionEvaluationException if an error occurs evaluating the function or derivative
      * @throws IllegalArgumentException if startValue is not between min and max or
      * if function is not a {@link DifferentiableUnivariateRealFunction} instance
@@ -141,7 +141,7 @@ public class NewtonSolver extends Univar
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function or derivative
+     * @throws FunctionEvaluationException if an error occurs evaluating the function or derivative
      * @throws IllegalArgumentException if startValue is not between min and max or
      * if function is not a {@link DifferentiableUnivariateRealFunction} instance

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/RiddersSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/RiddersSolver.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/RiddersSolver.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/RiddersSolver.java Tue Feb 15 01:31:12 2011
@@ -17,9 +17,9 @@
 package org.apache.commons.math.analysis.solvers;
 
 import org.apache.commons.math.ConvergenceException;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.util.FastMath;
 import org.apache.commons.math.util.MathUtils;
 
@@ -63,14 +63,14 @@ public class RiddersSolver extends Univa
     /** {@inheritDoc} */
     @Deprecated
     public double solve(final double min, final double max)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
         return solve(f, min, max);
     }
 
     /** {@inheritDoc} */
     @Deprecated
     public double solve(final double min, final double max, final double initial)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
         return solve(f, min, max, initial);
     }
 
@@ -86,13 +86,13 @@ public class RiddersSolver extends Univa
      * @param maxEval Maximum number of evaluations.
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max, final double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max, initial);
     }
@@ -108,14 +108,14 @@ public class RiddersSolver extends Univa
      * @param initial the start value to use
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
      */
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max, final double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
 
         // check for zeros before verifying bracketing
         if (f.value(min) == 0.0) { return min; }
@@ -142,13 +142,13 @@ public class RiddersSolver extends Univa
      * @param maxEval Maximum number of evaluations.
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max);
     }
@@ -163,14 +163,14 @@ public class RiddersSolver extends Univa
      * @param max the upper bound for the interval
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
      */
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
 
         // [x1, x2] is the bracketing interval in each iteration
         // x3 is the midpoint of [x1, x2]
@@ -86,13 +86,13 @@ public class RiddersSolver extends Univa
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
@@ -108,14 +108,14 @@ public class RiddersSolver extends Univa
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -142,13 +142,13 @@ public class RiddersSolver extends Univa
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      */
@@ -163,14 +163,14 @@ public class RiddersSolver extends Univa
      * @return the point at which the function value is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if any parameters are invalid
      * @deprecated in 2.2 (to be removed in 3.0).

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/SecantSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/SecantSolver.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/SecantSolver.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/SecantSolver.java Tue Feb 15 01:31:12 2011
@@ -17,10 +17,10 @@
 package org.apache.commons.math.analysis.solvers;
 
 import org.apache.commons.math.ConvergenceException;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.util.FastMath;
 
@@ -68,14 +68,14 @@ public class SecantSolver extends Univar
     /** {@inheritDoc} */
     @Deprecated
     public double solve(final double min, final double max)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
         return solve(f, min, max);
     }
 
     /** {@inheritDoc} */
     @Deprecated
     public double solve(final double min, final double max, final double initial)
-        throws ConvergenceException, MathUserException {
+        throws ConvergenceException, FunctionEvaluationException {
         return solve(f, min, max, initial);
     }
 
@@ -89,14 +89,14 @@ public class SecantSolver extends Univar
      * @param maxEval Maximum number of evaluations.
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max, final double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max, initial);
     }
@@ -110,7 +110,7 @@ public class SecantSolver extends Univar
      * @param initial the start value to use (ignored)
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -118,7 +118,7 @@ public class SecantSolver extends Univar
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max, final double initial)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         return solve(f, min, max);
     }
 
@@ -130,14 +130,14 @@ public class SecantSolver extends Univar
      * @param maxEval Maximum number of evaluations.
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException  if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
      */
     @Override
     public double solve(int maxEval, final UnivariateRealFunction f,
                         final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
         setMaximalIterationCount(maxEval);
         return solve(f, min, max);
     }
@@ -149,7 +149,7 @@ public class SecantSolver extends Univar
      * @param max the upper bound for the interval.
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException  if the maximum iteration count is exceeded
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
      * @deprecated in 2.2 (to be removed in 3.0).
@@ -157,7 +157,7 @@ public class SecantSolver extends Univar
     @Deprecated
     public double solve(final UnivariateRealFunction f,
                         final double min, final double max)
-        throws MaxIterationsExceededException, MathUserException {
+        throws MaxIterationsExceededException, FunctionEvaluationException {
 
         clearResult();
         verifyInterval(min, max);
@@ -89,14 +89,14 @@ public class SecantSolver extends Univar
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
@@ -110,7 +110,7 @@ public class SecantSolver extends Univar
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
@@ -130,14 +130,14 @@ public class SecantSolver extends Univar
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException  if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites
@@ -149,7 +149,7 @@ public class SecantSolver extends Univar
      * @return the value where the function is zero
      * @throws MaxIterationsExceededException  if the maximum iteration count is exceeded
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min is not less than max or the
      * signs of the values of the function at the endpoints are not opposites

Modified: commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/UnivariateRealSolver.java
URL: http://svn.apache.org/viewvc/commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/UnivariateRealSolver.java?rev=1070725&r1=1070724&r2=1070725&view=diff
==============================================================================
--- commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/UnivariateRealSolver.java (original)
+++ commons/proper/math/branches/MATH_2_X/src/main/java/org/apache/commons/math/analysis/solvers/UnivariateRealSolver.java Tue Feb 15 01:31:12 2011
@@ -18,8 +18,8 @@ package org.apache.commons.math.analysis
 
 import org.apache.commons.math.ConvergenceException;
 import org.apache.commons.math.ConvergingAlgorithm;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
-import org.apache.commons.math.exception.MathUserException;
 
 
 /**
@@ -69,14 +69,14 @@ public interface UnivariateRealSolver ex
      * @return a value where the function is zero
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise.
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min > max or the endpoints do not
      * satisfy the requirements specified by the solver
      * @deprecated replaced by {@link #solve(UnivariateRealFunction, double, double)}
      * since 2.0
      */
     @Deprecated
-    double solve(double min, double max) throws ConvergenceException, MathUserException;
+    double solve(double min, double max) throws ConvergenceException, FunctionEvaluationException;
 
     /**
      * Solve for a zero root in the given interval.
@@ -90,7 +90,7 @@ public interface UnivariateRealSolver ex
      * @return a value where the function is zero
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise.
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min > max or the endpoints do not
      * satisfy the requirements specified by the solver
      * @since 2.0
@@ -98,7 +98,7 @@ public interface UnivariateRealSolver ex
      */
     @Deprecated
     double solve(UnivariateRealFunction f, double min, double max)
-        throws ConvergenceException, MathUserException;
+        throws ConvergenceException, FunctionEvaluationException;
 
     /**
      * Solve for a zero in the given interval, start at startValue.
@@ -112,7 +112,7 @@ public interface UnivariateRealSolver ex
      * @return a value where the function is zero
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise.
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min > max or the arguments do not
      * satisfy the requirements specified by the solver
      * @deprecated replaced by {@link #solve(UnivariateRealFunction, double, double, double)}
@@ -120,7 +120,7 @@ public interface UnivariateRealSolver ex
      */
     @Deprecated
     double solve(double min, double max, double startValue)
-        throws ConvergenceException, MathUserException, IllegalArgumentException;
+        throws ConvergenceException, FunctionEvaluationException, IllegalArgumentException;
 
     /**
      * Solve for a zero in the given interval, start at startValue.
@@ -135,7 +135,7 @@ public interface UnivariateRealSolver ex
      * @return a value where the function is zero
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise.
      * @throws MathUserException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min > max or the arguments do not
      * satisfy the requirements specified by the solver
      * @since 2.0
@@ -143,7 +143,7 @@ public interface UnivariateRealSolver ex
      */
     @Deprecated
     double solve(UnivariateRealFunction f, double min, double max, double startValue)
-        throws ConvergenceException, MathUserException, IllegalArgumentException;
+        throws ConvergenceException, FunctionEvaluationException, IllegalArgumentException;
 
     /**
      * Get the result of the last run of the solver.
@@ -69,14 +69,14 @@ public interface UnivariateRealSolver ex
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise.
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min > max or the endpoints do not
      * satisfy the requirements specified by the solver
@@ -90,7 +90,7 @@ public interface UnivariateRealSolver ex
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise.
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min > max or the endpoints do not
      * satisfy the requirements specified by the solver
@@ -112,7 +112,7 @@ public interface UnivariateRealSolver ex
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise.
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min > max or the arguments do not
      * satisfy the requirements specified by the solver
@@ -135,7 +135,7 @@ public interface UnivariateRealSolver ex
      * @throws ConvergenceException if the maximum iteration count is exceeded
      * or the solver detects convergence problems otherwise.
-     * @throws MathUserException if an error occurs evaluating the function
+     * @throws FunctionEvaluationException if an error occurs evaluating the function
      * @throws IllegalArgumentException if min > max or the arguments do not
      * satisfy the requirements specified by the solver